summaryrefslogtreecommitdiffstats
path: root/kjsembed/qtbindings/qcanvaspixmaparray_imp.cpp
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-05 15:55:57 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-05 15:55:57 -0600
commit9ba04742771370f59740e32e11c5f3a1e6a1b70a (patch)
treec81c34dae2b3b1ea73801bf18a960265dc4207f7 /kjsembed/qtbindings/qcanvaspixmaparray_imp.cpp
parent1a96c45b22d01378202d9dc7ed9c47acd30f966e (diff)
downloadtdebindings-9ba04742771370f59740e32e11c5f3a1e6a1b70a.tar.gz
tdebindings-9ba04742771370f59740e32e11c5f3a1e6a1b70a.zip
Initial TQt conversion
Diffstat (limited to 'kjsembed/qtbindings/qcanvaspixmaparray_imp.cpp')
-rw-r--r--kjsembed/qtbindings/qcanvaspixmaparray_imp.cpp110
1 files changed, 55 insertions, 55 deletions
diff --git a/kjsembed/qtbindings/qcanvaspixmaparray_imp.cpp b/kjsembed/qtbindings/qcanvaspixmaparray_imp.cpp
index d3f249d9..73a6f58b 100644
--- a/kjsembed/qtbindings/qcanvaspixmaparray_imp.cpp
+++ b/kjsembed/qtbindings/qcanvaspixmaparray_imp.cpp
@@ -23,19 +23,19 @@
*/
namespace KJSEmbed {
-QCanvasPixmapArrayImp::QCanvasPixmapArrayImp( KJS::ExecState *exec, int mid, bool constructor )
+TTQCanvasPixmapArrayImp::TQCanvasPixmapArrayImp( KJS::ExecState *exec, int mid, bool constructor )
: JSProxyImp(exec), id(mid), cons(constructor)
{
}
-QCanvasPixmapArrayImp::~QCanvasPixmapArrayImp()
+TTQCanvasPixmapArrayImp::~TQCanvasPixmapArrayImp()
{
}
/**
* Adds bindings for static methods and enum constants to the specified Object.
*/
-void QCanvasPixmapArrayImp::addStaticBindings( KJS::ExecState *exec, KJS::Object &object )
+void TQCanvasPixmapArrayImp::addStaticBindings( KJS::ExecState *exec, KJS::Object &object )
{
JSProxy::MethodTable methods[] = {
@@ -43,11 +43,11 @@ void QCanvasPixmapArrayImp::addStaticBindings( KJS::ExecState *exec, KJS::Object
};
int idx = 0;
- TQCString lastName;
+ TTQCString lastName;
while( methods[idx].name ) {
if ( lastName != methods[idx].name ) {
- QCanvasPixmapArrayImp *meth = new QCanvasPixmapArrayImp( exec, methods[idx].id );
+ TQCanvasPixmapArrayImp *meth = new TQCanvasPixmapArrayImp( exec, methods[idx].id );
object.put( exec , methods[idx].name, KJS::Object(meth) );
lastName = methods[idx].name;
}
@@ -60,7 +60,7 @@ void QCanvasPixmapArrayImp::addStaticBindings( KJS::ExecState *exec, KJS::Object
/**
* Adds bindings for instance methods to the specified Object.
*/
-void QCanvasPixmapArrayImp::addBindings( KJS::ExecState *exec, KJS::Object &object )
+void TQCanvasPixmapArrayImp::addBindings( KJS::ExecState *exec, KJS::Object &object )
{
JSProxy::MethodTable methods[] = {
@@ -74,11 +74,11 @@ void QCanvasPixmapArrayImp::addBindings( KJS::ExecState *exec, KJS::Object &obje
};
int idx = 0;
- TQCString lastName;
+ TTQCString lastName;
while( methods[idx].name ) {
if ( lastName != methods[idx].name ) {
- QCanvasPixmapArrayImp *meth = new QCanvasPixmapArrayImp( exec, methods[idx].id );
+ TQCanvasPixmapArrayImp *meth = new TQCanvasPixmapArrayImp( exec, methods[idx].id );
object.put( exec , methods[idx].name, KJS::Object(meth) );
lastName = methods[idx].name;
}
@@ -87,82 +87,82 @@ void QCanvasPixmapArrayImp::addBindings( KJS::ExecState *exec, KJS::Object &obje
}
/**
* Extract a TQCanvasPixmapArray pointer from an Object.
*/
-TQCanvasPixmapArray *QCanvasPixmapArrayImp::toQCanvasPixmapArray( KJS::Object &self )
+TTQCanvasPixmapArray *TQCanvasPixmapArrayImp::toTQCanvasPixmapArray( KJS::Object &self )
{
JSObjectProxy *ob = JSProxy::toObjectProxy( self.imp() );
if ( ob ) {
- TQObject *obj = ob->object();
+ TTQObject *obj = ob->object();
if ( obj )
- return dynamic_cast<TQCanvasPixmapArray *>( obj );
+ return dynamic_cast<TTQCanvasPixmapArray *>( obj );
}
JSOpaqueProxy *op = JSProxy::toOpaqueProxy( self.imp() );
if ( !op )
return 0;
- if ( op->typeName() != "TQCanvasPixmapArray" )
+ if ( op->typeName() != "TTQCanvasPixmapArray" )
return 0;
- return op->toNative<TQCanvasPixmapArray>();
+ return op->toNative<TTQCanvasPixmapArray>();
}
/**
* Select and invoke the correct constructor.
*/
-KJS::Object QCanvasPixmapArrayImp::construct( KJS::ExecState *exec, const KJS::List &args )
+KJS::Object TQCanvasPixmapArrayImp::construct( KJS::ExecState *exec, const KJS::List &args )
{
switch( id ) {
case Constructor_QCanvasPixmapArray_1:
- return QCanvasPixmapArray_1( exec, args );
+ return TQCanvasPixmapArray_1( exec, args );
break;
case Constructor_QCanvasPixmapArray_2:
- return QCanvasPixmapArray_2( exec, args );
+ return TQCanvasPixmapArray_2( exec, args );
break;
case Constructor_QCanvasPixmapArray_3:
- return QCanvasPixmapArray_3( exec, args );
+ return TQCanvasPixmapArray_3( exec, args );
break;
case Constructor_QCanvasPixmapArray_4:
- return QCanvasPixmapArray_4( exec, args );
+ return TQCanvasPixmapArray_4( exec, args );
break;
default:
break;
}
- TQString msg = i18n("QCanvasPixmapArrayCons has no constructor with id '%1'.").arg(id);
+ TTQString msg = i18n("TQCanvasPixmapArrayCons has no constructor with id '%1'.").arg(id);
return throwError(exec, msg,KJS::ReferenceError);
}
-KJS::Object QCanvasPixmapArrayImp::QCanvasPixmapArray_1( KJS::ExecState *exec, const KJS::List &args )
+KJS::Object TQCanvasPixmapArrayImp::TQCanvasPixmapArray_1( KJS::ExecState *exec, const KJS::List &args )
{
- // We should now create an instance of the TQCanvasPixmapArray object
+ // We should now create an instance of the TTQCanvasPixmapArray object
- TQCanvasPixmapArray *ret = new TQCanvasPixmapArray(
+ TTQCanvasPixmapArray *ret = new TTQCanvasPixmapArray(
);
return KJS::Object();
}
-KJS::Object QCanvasPixmapArrayImp::QCanvasPixmapArray_2( KJS::ExecState *exec, const KJS::List &args )
+KJS::Object TQCanvasPixmapArrayImp::TQCanvasPixmapArray_2( KJS::ExecState *exec, const KJS::List &args )
{
- TQString arg0 = extractQString(exec, args, 0);
+ TTQString arg0 = extractTQString(exec, args, 0);
int arg1 = extractInt(exec, args, 1);
- // We should now create an instance of the TQCanvasPixmapArray object
+ // We should now create an instance of the TTQCanvasPixmapArray object
- TQCanvasPixmapArray *ret = new TQCanvasPixmapArray(
+ TTQCanvasPixmapArray *ret = new TTQCanvasPixmapArray(
arg0,
arg1 );
@@ -170,23 +170,23 @@ KJS::Object QCanvasPixmapArrayImp::QCanvasPixmapArray_2( KJS::ExecState *exec, c
}
-KJS::Object QCanvasPixmapArrayImp::QCanvasPixmapArray_3( KJS::ExecState *exec, const KJS::List &args )
+KJS::Object TQCanvasPixmapArrayImp::TQCanvasPixmapArray_3( KJS::ExecState *exec, const KJS::List &args )
{
// Unsupported parameter TQPtrList< TQPixmap >
return KJS::Object();
- TQPtrList< TQPixmap > arg0; // Dummy
+ TTQPtrList< TTQPixmap > arg0; // Dummy
- // Unsupported parameter TQPtrList< TQPoint >
+ // Unsupported parameter TTQPtrList< TTQPoint >
return KJS::Object();
- TQPtrList< TQPoint > arg1; // Dummy
+ TTQPtrList< TTQPoint > arg1; // Dummy
- // We should now create an instance of the TQCanvasPixmapArray object
+ // We should now create an instance of the TTQCanvasPixmapArray object
- TQCanvasPixmapArray *ret = new TQCanvasPixmapArray(
+ TTQCanvasPixmapArray *ret = new TTQCanvasPixmapArray(
arg0,
arg1 );
@@ -194,23 +194,23 @@ KJS::Object QCanvasPixmapArrayImp::QCanvasPixmapArray_3( KJS::ExecState *exec, c
}
-KJS::Object QCanvasPixmapArrayImp::QCanvasPixmapArray_4( KJS::ExecState *exec, const KJS::List &args )
+KJS::Object TQCanvasPixmapArrayImp::TQCanvasPixmapArray_4( KJS::ExecState *exec, const KJS::List &args )
{
// Unsupported parameter TQValueList< TQPixmap >
return KJS::Object();
- TQValueList< TQPixmap > arg0; // Dummy
+ TTQValueList< TTQPixmap > arg0; // Dummy
- // Unsupported parameter QPointArray
+ // Unsupported parameter TQPointArray
return KJS::Object();
- TQPointArray arg1; // Dummy
+ TTQPointArray arg1; // Dummy
- // We should now create an instance of the TQCanvasPixmapArray object
+ // We should now create an instance of the TTQCanvasPixmapArray object
- TQCanvasPixmapArray *ret = new TQCanvasPixmapArray(
+ TTQCanvasPixmapArray *ret = new TTQCanvasPixmapArray(
arg0,
arg1 );
@@ -218,9 +218,9 @@ KJS::Object QCanvasPixmapArrayImp::QCanvasPixmapArray_4( KJS::ExecState *exec, c
}
-KJS::Value QCanvasPixmapArrayImp::call( KJS::ExecState *exec, KJS::Object &self, const KJS::List &args )
+KJS::Value TQCanvasPixmapArrayImp::call( KJS::ExecState *exec, KJS::Object &self, const KJS::List &args )
{
- instance = QCanvasPixmapArrayImp::toQCanvasPixmapArray( self );
+ instance = TQCanvasPixmapArrayImp::toTQCanvasPixmapArray( self );
switch( id ) {
@@ -252,15 +252,15 @@ KJS::Value QCanvasPixmapArrayImp::call( KJS::ExecState *exec, KJS::Object &self,
break;
}
- TQString msg = i18n( "QCanvasPixmapArrayImp has no method with id '%1'." ).arg( id );
+ TTQString msg = i18n( "TQCanvasPixmapArrayImp has no method with id '%1'." ).arg( id );
return throwError(exec, msg,KJS::ReferenceError);
}
-KJS::Value QCanvasPixmapArrayImp::readPixmaps_6( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
+KJS::Value TQCanvasPixmapArrayImp::readPixmaps_6( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
- TQString arg0 = extractQString(exec, args, 0);
+ TTQString arg0 = extractTQString(exec, args, 0);
int arg1 = extractInt(exec, args, 1);
@@ -272,10 +272,10 @@ KJS::Value QCanvasPixmapArrayImp::readPixmaps_6( KJS::ExecState *exec, KJS::Obje
}
-KJS::Value QCanvasPixmapArrayImp::readCollisionMasks_7( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
+KJS::Value TQCanvasPixmapArrayImp::readCollisionMasks_7( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
- TQString arg0 = extractQString(exec, args, 0);
+ TTQString arg0 = extractTQString(exec, args, 0);
bool ret;
ret = instance->readCollisionMasks(
@@ -284,7 +284,7 @@ KJS::Value QCanvasPixmapArrayImp::readCollisionMasks_7( KJS::ExecState *exec, KJ
}
-KJS::Value QCanvasPixmapArrayImp::isValid_9( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
+KJS::Value TQCanvasPixmapArrayImp::isValid_9( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
bool ret;
@@ -293,26 +293,26 @@ KJS::Value QCanvasPixmapArrayImp::isValid_9( KJS::ExecState *exec, KJS::Object &
}
-KJS::Value QCanvasPixmapArrayImp::image_10( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
+KJS::Value TQCanvasPixmapArrayImp::image_10( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
int arg0 = extractInt(exec, args, 0);
instance->image(
arg0 );
- return KJS::Value(); // Returns 'TQCanvasPixmap *'
+ return KJS::Value(); // Returns 'TTQCanvasPixmap *'
}
-KJS::Value QCanvasPixmapArrayImp::setImage_11( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
+KJS::Value TQCanvasPixmapArrayImp::setImage_11( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
int arg0 = extractInt(exec, args, 0);
// Unsupported parameter TQCanvasPixmap *
return KJS::Value();
- TQCanvasPixmap * arg1; // Dummy
+ TTQCanvasPixmap * arg1; // Dummy
instance->setImage(
arg0,
@@ -321,7 +321,7 @@ KJS::Value QCanvasPixmapArrayImp::setImage_11( KJS::ExecState *exec, KJS::Object
}
-KJS::Value QCanvasPixmapArrayImp::count_12( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
+KJS::Value TQCanvasPixmapArrayImp::count_12( KJS::ExecState *exec, KJS::Object &obj, const KJS::List &args )
{
uint ret;
@@ -87,82 +87,82 @@ void QCanvasPixmapArrayImp::addBindings( KJS::ExecState *exec, KJS::Object &obje
}
/**
- * Extract a TQCanvasPixmapArray pointer from an Object.
+ * Extract a TTQCanvasPixmapArray pointer from an Object.
*/
@@ -170,23 +170,23 @@ KJS::Object QCanvasPixmapArrayImp::QCanvasPixmapArray_2( KJS::ExecState *exec, c
{
- // Unsupported parameter TQPtrList< TQPixmap >
+ // Unsupported parameter TTQPtrList< TTQPixmap >
return KJS::Object();
@@ -194,23 +194,23 @@ KJS::Object QCanvasPixmapArrayImp::QCanvasPixmapArray_3( KJS::ExecState *exec, c
{
- // Unsupported parameter TQValueList< TQPixmap >
+ // Unsupported parameter TTQValueList< TTQPixmap >
return KJS::Object();
@@ -293,26 +293,26 @@ KJS::Value QCanvasPixmapArrayImp::isValid_9( KJS::ExecState *exec, KJS::Object &
{
int arg0 = extractInt(exec, args, 0);
- // Unsupported parameter TQCanvasPixmap *
+ // Unsupported parameter TTQCanvasPixmap *
return KJS::Value();